@@ -1,8 +1,12 @@
 import re
 from os.path import normpath
 from pathlib import Path
+from typing import List
+
+from markdown.inlinepatterns import Pattern
 
 from markdownup.auth.auth_provider import AuthProvider
+from markdownup.cache.cache import Cache
 from markdownup.config import Config
 from markdownup.filesystem.asset_file import AssetFile
 from markdownup.filesystem.directory import Directory
@@ -14,11 +18,12 @@ class MarkdownUp:
 
     def __init__(self, config: Config):
         self.config = config
-        self.exclusions = list(map(lambda e: re.compile(e), config.get('content', 'exclusions')))
-        self.root_path = Path(config.get('content', 'root')).resolve()
-        self.root = Directory(self)
-        self.theme = Theme(config)
-        self.auth_provider = AuthProvider.instance(config)
+        self.cache: Cache = Cache.instance(self)
+        self.exclusions: List[Pattern] = list(map(lambda e: re.compile(e), config.get('content', 'exclusions')))
+        self.root_path: Path = Path(config.get('content', 'root')).resolve()
+        self.root: Directory = Directory(self)
+        self.theme: Theme = Theme(config)
+        self.auth_provider: AuthProvider = AuthProvider.instance(self)
 
     def wsgi_app(self, environ, start_response):
         print(environ['REQUEST_METHOD'] + ' ' + environ['PATH_INFO'])
@@ -38,9 +43,6 @@ class MarkdownUp:
 
         response = self.get(environ['PATH_INFO'] or '/', environ)
 
-        if self.auth_provider:
-            response = self.auth_provider.handle_response(environ, response)
-
         return response
 
     def get(self, path: str, environ=None) -> 'Response':
